pub struct InputScript {
pub witness: Vec<Vec<u8>>,
pub sig_script: Vec<u8>,
}Fields
witness: Vec<Vec<u8>>The serializes witness stack for the specified input.
sig_script: Vec<u8>The optional sig script for the specified witness that will only be set if the input specified is a nested p2sh witness program.