pub struct LabelTransactionRequest {
pub txid: Vec<u8>,
pub label: String,
pub overwrite: bool,
}Fields
txid: Vec<u8>The txid of the transaction to label.
label: StringThe label to add to the transaction, limited to 500 characters.
overwrite: boolWhether to overwrite the existing label, if it is present.